summaryrefslogtreecommitdiff
path: root/util/pinmap/pm/reader.go
diff options
context:
space:
mode:
Diffstat (limited to 'util/pinmap/pm/reader.go')
-rw-r--r--util/pinmap/pm/reader.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/util/pinmap/pm/reader.go b/util/pinmap/pm/reader.go
index d518b7fc3a..08dbb9e3af 100644
--- a/util/pinmap/pm/reader.go
+++ b/util/pinmap/pm/reader.go
@@ -11,18 +11,18 @@ import (
// Reader reads the pin configuration from a source.
type Reader interface {
Name() string
- Read(arg string, chip string) (*Pins, error)
+ Read(key string, arg string) (*Pins, error)
}
// readerlist is registered list of readers.
var readerList []Reader
// ReadPins will use the selected reader and the chip to
// read the EC pin data.
-func ReadPins(reader, chip, arg string) (*Pins, error) {
+func ReadPins(reader, key, arg string) (*Pins, error) {
for _, r := range readerList {
if r.Name() == reader {
- return r.Read(chip, arg)
+ return r.Read(key, arg)
}
}
return nil, fmt.Errorf("%s: unknown reader", reader)
@@ -11,18 +11,18 @@ import (
// readerlist is registered list of readers.
var readerList []Reader
-// ReadPins will use the selected reader and the chip to
+// ReadPins will use the selected reader and the key to
// read the EC pin data.